
"""bioticDETR package initialization.

See package README for introduction.

"""


import logging


logger = logging.getLogger(__name__)
"""Module logger."""


class bioticDETRError(Exception):
    """Base exception class for errors in this package."""
